BleError

Enum BleError 

#[non_exhaustive]
pub enum BleError { Tlv8(Tlv8Error), Crypto(CryptoError), Model(ModelError), AccessoryNotFound, CharacteristicNotFound { aid: u64, iid: u64, }, MalformedPdu(&'static str), PairingRejected(u8), Disconnected, Backend(String), }
Errors from the BLE transport.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Tlv8(Tlv8Error)

Malformed TLV8 in a PDU body or pairing message.



Crypto(CryptoError)

A pairing or AEAD crypto operation failed.



Model(ModelError)

The accessory attribute model could not be built or coerced.



AccessoryNotFound

No accessory matched the discovery filter.



CharacteristicNotFound

The requested characteristic is not in the accessory’s database.

Fields

aid: u64

Accessory instance id.

iid: u64

Characteristic instance id.



MalformedPdu(&'static str)

A received HAP-BLE PDU was malformed.



PairingRejected(u8)

The accessory rejected a pairing step with a non-zero status.



Disconnected

The BLE link dropped mid-operation.



Backend(String)

An error from the BLE backend (transport-library specific).